"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateHooks = void 0;
const toHookName_1 = require("./toHookName");
function generateHooks(tableName) {
    const hooks = [];
    hooks.push(`export function ${(0, toHookName_1.toHookName)(tableName, 'Get')}(id: string) {
  return useQuery<Database['public']['Tables']['${tableName}']['Row'], Error>(
    ['${tableName}', id],
    async () => {
      const { data, error } = await supabase
        .from<Database['public']['Tables']['${tableName}']['Row']>('${tableName}')
        .select('*')
        .eq('id', id)
        .single();

      if (error) {
        throw error;
      }

      if (!data) {
        throw new Error('No data found');
      }

      return data;
    },
    {
      enabled: !!id,
    }
  );
}`, `export function ${(0, toHookName_1.toHookName)(tableName, 'GetAll')}() {
  return useQuery<Database['public']['Tables']['${tableName}']['Row'][], Error>(['${tableName}'], async () => {
    const { data, error } = await supabase.from<Database['public']['Tables']['${tableName}']['Row']>('${tableName}').select();
    if (error) throw error;
    return data as Database['public']['Tables']['${tableName}']['Row'][];
  });
}`, `export function ${(0, toHookName_1.toHookName)(tableName, 'Add')}() {
  const queryClient = useQueryClient();
  return useMutation((item: Database['public']['Tables']['${tableName}']['Insert']) => supabase.from<Database['public']['Tables']['${tableName}']['Row']>('${tableName}').insert(item).single(), {
    onSuccess: () => {
      queryClient.invalidateQueries('${tableName}');
    },
  });
}`, `export function ${(0, toHookName_1.toHookName)(tableName, 'Update')}() {
  const queryClient = useQueryClient();
  return useMutation((item: { id: string; changes: Database['public']['Tables']['${tableName}']['Update'] }) => supabase.from<Database['public']['Tables']['${tableName}']['Row']>('${tableName}').update(item.changes).eq('id', item.id).single(), {
    onSuccess: () => {
      queryClient.invalidateQueries('${tableName}');
    },
  });
}`, `export function ${(0, toHookName_1.toHookName)(tableName, 'Delete')}() {
  const queryClient = useQueryClient();
  return useMutation((id: string) => supabase.from<Database['public']['Tables']['${tableName}']['Row']>('${tableName}').delete().eq('id', id).single(), {
    onSuccess: () => {
      queryClient.invalidateQueries('${tableName}');
    },
  });
}`);
    return hooks;
}
exports.generateHooks = generateHooks;
